@@ -1,6 +1,6 @@
 /*
  *	tardy - a tar post-processor
- *	Copyright (C) 1998, 1999 Peter Miller;
+ *	Copyright (C) 1998, 1999, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,15 +25,39 @@
 
 #include <file/input.h>
 
+/**
+  * The file_input_stdin is used to represent input from the process's
+  * standard input stream.
+  */
 class file_input_stdin: public file_input
 {
-	public:
-	~file_input_stdin();
-	file_input_stdin();
-	file_input_stdin(const file_input_stdin &);
-	file_input_stdin &operator = (const file_input_stdin &);
-	virtual int read(void *, int) const;
-	virtual const char *filename() const;
+public:
+    /**
+      * The destructor.
+      */
+    ~file_input_stdin();
+
+    /**
+      * The default constructor.
+      */
+    file_input_stdin();
+
+    // See base class for documentation.
+    virtual int read(void *data, int nbytes) const;
+
+    // See base class for documentation.
+    virtual const char *filename() const;
+
+private:
+    /**
+      * The copy constructor.  Do not use.
+      */
+    file_input_stdin(const file_input_stdin &);
+
+    /**
+      * The assignment operator.  Do not use.
+      */
+    file_input_stdin &operator = (const file_input_stdin &);
 };
 
 #endif /* COMMON_FILE_INPUT_STDIN_H */
