@@ -1,6 +1,6 @@
 /*
  *	tardy - a tar post-processor
- *	Copyright (C) 1993, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1993, 1998, 1999, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,15 @@
 #define SIZEOF(a) (sizeof(a) / sizeof(a[0]))
 #define ENDOF(a) ((a) + SIZEOF(a))
 
+/*
+ * Printf formatting attributes.
+ */
+#ifdef __GNUC__
+#define ATTR_PRINTF(x, y) __attribute__((__format__(printf, x, y)))
+#else
+#define ATTR_PRINTF(x, y)
+#endif
+
 /*
  * Take the define out of comments to
  * enable the debugging the functionality.
