@@ -1,6 +1,6 @@
 /*
  *	tardy - a tar post-processor
- *	Copyright (C) 1991-1995, 1998, 1999, 2001, 2002 Peter Miller;
+ *	Copyright (C) 1991-1995, 1998, 1999, 2001, 2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -366,7 +366,7 @@ version_main(void)
 			s1 = str_from_c(hit[0]->name);
 			for (j = 1; j < nhit; ++j)
 			{
-				s2 = str_format("%S, %s", s1, hit[j]->name);
+				s2 = str_format("%s, %s", s1->str_text, hit[j]->name);
 				str_free(s1);
 				s1 = s2;
 			}
